@@ -165,10 +165,9 @@ class NxPyDocs():
 
     def clone(self):
         os.system("git clone %s nxpydocs" % self.repo)
-        os.system("cd nxpydocs")           
+        os.chdir("nxpydocs")           
 
     def send_to_repo(self):
-        os.system("git clone %s" % self.repo)
         os.system("git add *")
         os.system("git commit -am 'nxpydocs generated this commit")
         os.system("git push")
